@@ -8,6 +8,7 @@ from .issue_comment import (
 from .release import ReleaseCreatedEvent, ReleaseReleasedEvent
 from .status import StatusEvent
 from .push import PushEvent
+from .issues import IssuesEvent, IssueOpenedEvent
 
 __all__ = [
     "CreateBranchEvent",
@@ -20,5 +21,7 @@ __all__ = [
     "ReleaseCreatedEvent",
     "ReleaseReleasedEvent",
     "StatusEvent",
-    "PushEvent"
+    "PushEvent",
+    "IssuesEvent",
+    "IssueOpenedEvent",
 ]
